#!/usr/bin/perl -w

# Bumps a version number in the "VERSION" file, with datestamp on next line.
# Logs same to history file, with message.
# Examples:
#
# bumpver maj 'Added true PID controller'
# bumpver min 'Added "maxalarm" option'
# bumpver fix 'Corrected spelling of "sensor"'

use strict;
use warnings;
use v5.020;
use English qw( -no_match_vars );
use autodie qw( :all );
use POSIX qw( strftime );

my $verfile  = 'VERSION';
my $histfile = 'HISTORY';

my $fh;

# arguments

my $mode = shift @ARGV;
die 'missing argument: mode' unless $mode;

my $msg = shift @ARGV;
die 'missing argument: message' unless $msg;

die 'too many arguments' if @ARGV;

# get old ver

open ($fh, '<', $verfile);
my $old = <$fh>;
close $fh;
chomp $old;
say "Old: $old";

my ($maj, $min, $fix) = split /\./, $old;

# incremenet

if ($mode eq 'maj') {
	$maj++;
	$min = $fix = 0;
	}
elsif ($mode eq 'min') {
	$min++;
	$fix = 0;
	}
elsif ($mode eq 'fix') {
	$fix++;
	}
else {
	die "bad mode: $mode";
	}

# build new ver

my $new = "$maj.$min.$fix";
say "New: $new";

my $when = strftime('%Y-%m-%d', gmtime);
say "When: $when";

# write state

open ($fh, '>', $verfile);
say {$fh} $new;
say {$fh} $when;
close $fh;

# write history

open ($fh, '>>', $histfile);
say {$fh} "$when $new $msg";
close $fh;
