#!/usr/bin/perl -w

use strict;
use warnings;
use 5.020;

use Perl::Critic;
use Perl::Critic::Violation;

Perl::Critic::Violation::set_format(
	"%f:%L: SEV%s %p\n\t>>> %r\n\t%m\n\t%e\n\n");

my $critic = Perl::Critic->new(
	-severity	=> 'brutal',
	-verbose	=> 11,
	-exclude	=> [
		# many of these are false positives
		# some have the right idea but poor Critic implementation
		# some are OK in some scenarios, but not this one
		# some are legit but there is no better alternative
		# some I just disagree with
		'ValuesAndExpressions::ProhibitConstantPragma',
		'Subroutines::ProhibitSubroutinePrototypes',
		'ValuesAndExpressions::ProhibitNoisyQuotes',
		'Variables::ProhibitPunctuationVars',
		'CodeLayout::ProhibitHardTabs',
		'Variables::RequireLocalizedPunctuationVars',
		'ControlStructures::ProhibitPostfixControls',
		'ErrorHandling::RequireCarping',
		'Subroutines::RequireFinalReturn',
		'RegularExpressions::RequireDotMatchAnything',
		'RegularExpressions::RequireExtendedFormatting',
		'RegularExpressions::RequireLineBoundaryMatching',
		'CodeLayout::ProhibitParensWithBuiltins',
		'InputOutput::RequireBriefOpen',
		'Modules::ProhibitExcessMainComplexity',
		'Modules::RequireVersionVar',
		'ValuesAndExpressions::ProhibitVersionStrings',
		'ControlStructures::ProhibitNegativeExpressionsInUnlessAndUntilConditions',
		'ControlStructures::ProhibitCascadingIfElse',
		]
	);

my @violations = $critic->critique('guardcat');

say @violations;
